@@ -1,3 +1,17 @@
+#' @keywords internal
+#' @noRd
+plot_with_settings_deps <- function() {
+  htmltools::htmlDependency(
+    name = "teal-widgets-plot-with-settings",
+    version = utils::packageVersion("teal.widgets"),
+    package = "teal.widgets",
+    src = "plot-with-settings",
+    script = "plot-with-settings.js",
+    stylesheet = "plot-with-settings.css"
+  )
+}
+
+#' @name plot_with_settings
 #' @rdname plot_with_settings
 #' @export
 plot_with_settings_ui <- function(id) {
@@ -6,31 +20,7 @@ plot_with_settings_ui <- function(id) {
   ns <- NS(id)
 
   tagList(
-    shiny::singleton(shiny::tags$head(
-      shiny::tags$script(
-        # nolint start
-        sprintf(
-          '$(document).on("shiny:connected", function(e) {
-            Shiny.onInputChange("%s", document.getElementById("%s").clientWidth);
-            Shiny.onInputChange("%s", 0.87*window.innerWidth);
-            //based on modal CSS property, also accounting for margins
-          });
-          $(window).resize(function(e) {
-            Shiny.onInputChange("%s", document.getElementById("%s").clientWidth);
-            Shiny.onInputChange("%s", 0.87*window.innerWidth);
-            //based on modal CSS property, also accounting for margins
-          });',
-          # nolint end
-          ns("flex_width"), # session input$ variable name
-          ns("plot_out_main"), # graph parent id
-          ns("plot_modal_width"), # session input$ variable name
-          ns("flex_width"), # session input$ variable name
-          ns("plot_out_main"), # graph parent id
-          ns("plot_modal_width") # session input$ variable name
-        )
-      )
-    )),
-    include_css_files("plot_with_settings"),
+    plot_with_settings_deps(),
     tags$div(
       id = ns("plot-with-settings"),
       tags$div(
@@ -44,6 +34,7 @@ plot_with_settings_ui <- function(id) {
         ),
         shinyWidgets::dropdownButton(
           circle = FALSE,
+          size = "sm",
           icon = icon("maximize"),
           inline = TRUE,
           right = TRUE,
@@ -61,7 +52,7 @@ plot_with_settings_ui <- function(id) {
 #' Plot-with-settings module
 #'
 #' @rdname plot_with_settings
-#' @description `r lifecycle::badge("stable")`
+#' @description `r lifecycle::badge("stable")`\cr
 #' Universal module for plots with settings for height, width, and download.
 #'
 #' @export
@@ -72,33 +63,33 @@ plot_with_settings_ui <- function(id) {
 #'  `reactive` expression or a simple `function` to draw a plot.
 #'  A simple `function` is needed e.g. for base plots like `plot(1)` as the output can not be caught when downloading.
 #'  Take into account that simple functions are less efficient than reactive, as not catching the result.
-#' @param height (`numeric`, optional)\cr
+#' @param height (`numeric`) optional\cr
 #'  vector with three elements c(VAL, MIN, MAX), where VAL is the starting value of the slider in
 #'  the main and modal plot display. The value in the modal display is taken from the value of the
 #'  slider in the main plot display.
-#' @param width (`numeric`, optional)\cr
+#' @param width (`numeric`) optional\cr
 #'  vector with three elements `c(VAL, MIN, MAX)`, where VAL is the starting value of the slider in
 #'  the main and modal plot display; `NULL` for default display. The value in the modal
 #'  display is taken from the value of the slider in the main plot display.
-#' @param show_hide_signal optional, (\code{reactive logical} a mechanism to allow modules which call this
+#' @param show_hide_signal optional, (`reactive logical` a mechanism to allow modules which call this
 #'     module to show/hide the plot_with_settings UI)
-#' @param brushing (`logical`, optional)\cr
-#'  a mechanism to enable / disable brushing on the main plot (in particular: not the one displayed
+#' @param brushing (`logical`) optional\cr
+#'  mechanism to enable / disable brushing on the main plot (in particular: not the one displayed
 #'  in modal). All the brushing data is stored as a reactive object in the `"brush"` element of
 #'  returned list. See the example for details.
 #' @param clicking (`logical`)\cr
 #'  a mechanism to enable / disable clicking on data points on the main plot (in particular: not the
 #'  one displayed in modal). All the clicking data is stored as a reactive object in the `"click"`
 #'  element of returned list. See the example for details.
-#' @param dblclicking (`logical`, optional)\cr
-#'  a mechanism to enable / disable double-clicking on data points on the main plot (in particular:
+#' @param dblclicking (`logical`) optional\cr
+#'  mechanism to enable / disable double-clicking on data points on the main plot (in particular:
 #'  not the one displayed in modal). All the double clicking data is stored as a reactive object in
 #'  the `"dblclick"` element of returned list. See the example for details.
-#' @param hovering (`logical(1)`, optional)\cr
-#'  a mechanism to enable / disable hovering over data points on the main plot (in particular: not
+#' @param hovering (`logical(1)`) optional\cr
+#'  mechanism to enable / disable hovering over data points on the main plot (in particular: not
 #'  the one displayed in modal). All the hovering data is stored as a reactive object in the
 #' `"hover"` element of returned list. See the example for details.
-#' @param graph_align (`character(1)`, optional)\cr
+#' @param graph_align (`character(1)`) optional,\cr
 #'  one of `"left"` (default), `"center"`, `"right"` or `"justify"`. The alignment of the graph on
 #'  the main page.
 #'
@@ -111,145 +102,145 @@ plot_with_settings_ui <- function(id) {
 #' @examples
 #' # Example using a reactive as input to plot_r
 #' library(shiny)
-#' app1 <- shinyApp(
-#'   ui = fluidPage(
-#'     plot_with_settings_ui(
-#'       id = "plot_with_settings"
-#'     )
-#'   ),
-#'   server = function(input, output, session) {
-#'     plot_r <- reactive({
-#'       ggplot2::ggplot(faithful, ggplot2::aes(x = waiting, y = eruptions)) +
-#'         ggplot2::geom_point()
-#'     })
+#' library(ggplot2)
 #'
-#'     plot_with_settings_srv(
-#'       id = "plot_with_settings",
-#'       plot_r = plot_r,
-#'       height = c(400, 100, 1200),
-#'       width = c(500, 250, 750)
-#'     )
-#'   }
+#' ui <- fluidPage(
+#'   plot_with_settings_ui(
+#'     id = "plot_with_settings"
+#'   )
 #' )
 #'
+#' server <- function(input, output, session) {
+#'   plot_r <- reactive({
+#'     ggplot(faithful, aes(x = .data$waiting, y = .data$eruptions)) +
+#'       geom_point()
+#'   })
+#'
+#'   plot_with_settings_srv(
+#'     id = "plot_with_settings",
+#'     plot_r = plot_r,
+#'     height = c(400, 100, 1200),
+#'     width = c(500, 250, 750)
+#'   )
+#' }
+#'
 #' if (interactive()) {
-#'   shinyApp(app1$ui, app1$server)
+#'   shinyApp(ui, server)
 #' }
 #'
 #' # Example using a function as input to plot_r
-#' app2 <- shinyApp(
-#'   ui = fluidPage(
-#'     radioButtons("download_option", "Select the Option", list("ggplot", "trellis", "grob", "base")),
-#'     plot_with_settings_ui(
-#'       id = "plot_with_settings"
-#'     ),
-#'     sliderInput("nums", "Value", 1, 10, 1)
-#'   ),
-#'   server = function(input, output, session) {
-#'     plot_r <- function() {
-#'       numbers <- seq_len(input$nums)
-#'       if (input$download_option == "ggplot") {
-#'         ggplot2::ggplot(data.frame(n = numbers), ggplot2::aes(n)) +
-#'           ggplot2::geom_bar()
-#'       } else if (input$download_option == "trellis") {
-#'         lattice::densityplot(numbers)
-#'       } else if (input$download_option == "grob") {
-#'         tr_plot <- lattice::densityplot(numbers)
-#'         ggplot2::ggplotGrob(
-#'           ggplot2::ggplot(data.frame(n = numbers), ggplot2::aes(n)) +
-#'             ggplot2::geom_bar()
-#'         )
-#'       } else if (input$download_option == "base") {
-#'         plot(numbers)
-#'       }
-#'     }
+#' library(lattice)
 #'
-#'     plot_with_settings_srv(
-#'       id = "plot_with_settings",
-#'       plot_r = plot_r,
-#'       height = c(400, 100, 1200),
-#'       width = c(500, 250, 750)
-#'     )
-#'   }
+#' ui <- fluidPage(
+#'   radioButtons("download_option", "Select the Option", list("ggplot", "trellis", "grob", "base")),
+#'   plot_with_settings_ui(
+#'     id = "plot_with_settings"
+#'   ),
+#'   sliderInput("nums", "Value", 1, 10, 1)
 #' )
 #'
+#' server <- function(input, output, session) {
+#'   plot_r <- function() {
+#'     numbers <- seq_len(input$nums)
+#'     if (input$download_option == "ggplot") {
+#'       ggplot(data.frame(n = numbers), aes(.data$n)) +
+#'         geom_bar()
+#'     } else if (input$download_option == "trellis") {
+#'       densityplot(numbers)
+#'     } else if (input$download_option == "grob") {
+#'       tr_plot <- densityplot(numbers)
+#'       ggplotGrob(
+#'         ggplot(data.frame(n = numbers), aes(.data$n)) +
+#'           geom_bar()
+#'       )
+#'     } else if (input$download_option == "base") {
+#'       plot(numbers)
+#'     }
+#'   }
+#'
+#'   plot_with_settings_srv(
+#'     id = "plot_with_settings",
+#'     plot_r = plot_r,
+#'     height = c(400, 100, 1200),
+#'     width = c(500, 250, 750)
+#'   )
+#' }
+#'
 #' if (interactive()) {
-#'   shinyApp(app2$ui, app2$server)
+#'   shinyApp(ui, server)
 #' }
 #'
 #' # Example with brushing/hovering/clicking/double-clicking
-#' app3 <- shinyApp(
-#'   ui = fluidPage(
-#'     plot_with_settings_ui(
-#'       id = "plot_with_settings"
-#'     ),
-#'     fluidRow(
-#'       column(4, h3("Brush"), verbatimTextOutput("brushing_data")),
-#'       column(4, h3("Click"), verbatimTextOutput("clicking_data")),
-#'       column(4, h3("DblClick"), verbatimTextOutput("dblclicking_data")),
-#'       column(4, h3("Hover"), verbatimTextOutput("hovering_data"))
-#'     )
+#' ui <- fluidPage(
+#'   plot_with_settings_ui(
+#'     id = "plot_with_settings"
 #'   ),
-#'   server = function(input, output, session) {
-#'     plot_r <- reactive({
-#'       ggplot2::ggplot(faithful, ggplot2::aes(x = waiting, y = eruptions)) +
-#'         ggplot2::geom_point()
-#'     })
-#'
-#'     plot_data <- plot_with_settings_srv(
-#'       id = "plot_with_settings",
-#'       plot_r = plot_r,
-#'       height = c(400, 100, 1200),
-#'       brushing = TRUE,
-#'       clicking = TRUE,
-#'       dblclicking = TRUE,
-#'       hovering = TRUE
-#'     )
-#'
-#'     output$brushing_data <- renderPrint(plot_data$brush())
-#'     output$clicking_data <- renderPrint(plot_data$click())
-#'     output$dblclicking_data <- renderPrint(plot_data$dblclick())
-#'     output$hovering_data <- renderPrint(plot_data$hover())
-#'   }
+#'   fluidRow(
+#'     column(4, tags$h3("Brush"), verbatimTextOutput("brushing_data")),
+#'     column(4, tags$h3("Click"), verbatimTextOutput("clicking_data")),
+#'     column(4, tags$h3("DblClick"), verbatimTextOutput("dblclicking_data")),
+#'     column(4, tags$h3("Hover"), verbatimTextOutput("hovering_data"))
+#'   )
 #' )
 #'
+#' server <- function(input, output, session) {
+#'   plot_r <- reactive({
+#'     ggplot(faithful, aes(x = .data$waiting, y = .data$eruptions)) +
+#'       geom_point()
+#'   })
+#'
+#'   plot_data <- plot_with_settings_srv(
+#'     id = "plot_with_settings",
+#'     plot_r = plot_r,
+#'     height = c(400, 100, 1200),
+#'     brushing = TRUE,
+#'     clicking = TRUE,
+#'     dblclicking = TRUE,
+#'     hovering = TRUE
+#'   )
+#'
+#'   output$brushing_data <- renderPrint(plot_data$brush())
+#'   output$clicking_data <- renderPrint(plot_data$click())
+#'   output$dblclicking_data <- renderPrint(plot_data$dblclick())
+#'   output$hovering_data <- renderPrint(plot_data$hover())
+#' }
+#'
 #' if (interactive()) {
-#'   shinyApp(app3$ui, app3$server)
+#'   shinyApp(ui, server)
 #' }
 #'
 #' # Example which allows module to be hidden/shown
 #' library("shinyjs")
 #'
-#' app4 <- shinyApp(
-#'   ui = fluidPage(
-#'     useShinyjs(),
-#'     actionButton("button", "Show/Hide"),
-#'     plot_with_settings_ui(
-#'       id = "plot_with_settings"
-#'     )
-#'   ),
-#'   server = function(input, output, session) {
-#'     plot_r <- plot_r <- reactive(
-#'       ggplot2::ggplot(faithful, ggplot2::aes(x = waiting, y = eruptions)) +
-#'         ggplot2::geom_point()
-#'     )
-#'
-#'     show_hide_signal_rv <- reactiveVal(TRUE)
-#'
-#'     observeEvent(input$button, show_hide_signal_rv(!show_hide_signal_rv()))
-#'
-#'     plot_with_settings_srv(
-#'       id = "plot_with_settings",
-#'       plot_r = plot_r,
-#'       height = c(400, 100, 1200),
-#'       width = c(500, 250, 750),
-#'       show_hide_signal = reactive(show_hide_signal_rv())
-#'     )
-#'   }
+#' ui <- fluidPage(
+#'   useShinyjs(),
+#'   actionButton("button", "Show/Hide"),
+#'   plot_with_settings_ui(
+#'     id = "plot_with_settings"
+#'   )
 #' )
 #'
+#' server <- function(input, output, session) {
+#'   plot_r <- plot_r <- reactive(
+#'     ggplot(faithful, aes(x = .data$waiting, y = .data$eruptions)) +
+#'       geom_point()
+#'   )
+#'
+#'   show_hide_signal_rv <- reactiveVal(TRUE)
+#'
+#'   observeEvent(input$button, show_hide_signal_rv(!show_hide_signal_rv()))
+#'
+#'   plot_with_settings_srv(
+#'     id = "plot_with_settings",
+#'     plot_r = plot_r,
+#'     height = c(400, 100, 1200),
+#'     width = c(500, 250, 750),
+#'     show_hide_signal = reactive(show_hide_signal_rv())
+#'   )
+#' }
+#'
 #' if (interactive()) {
-#'   shinyApp(app4$ui, app4$server)
+#'   shinyApp(ui, server)
 #' }
 #'
 plot_with_settings_srv <- function(id,
@@ -283,6 +274,14 @@ plot_with_settings_srv <- function(id,
 
   moduleServer(id, function(input, output, session) {
     ns <- session$ns
+    shinyjs::runjs(
+      sprintf(
+        'establishPlotResizing("%s", "%s", "%s");',
+        ns("plot_main"), # graph parent id
+        ns("flex_width"), # session input$ variable name
+        ns("plot_modal_width") # session input$ variable name
+      )
+    )
     default_w <- function() session$clientData[[paste0("output_", ns("plot_main_width"))]]
     default_h <- function() session$clientData[[paste0("output_", ns("plot_main_height"))]]
 
@@ -331,7 +330,7 @@ plot_with_settings_srv <- function(id,
     })
 
     output$slider_ui <- renderUI({
-      div(
+      tags$div(
         optionalSliderInputValMinMax(
           inputId = ns("height"),
           label = "Plot height",
@@ -383,8 +382,19 @@ plot_with_settings_srv <- function(id,
       }
     })
 
-    p_height <- reactive(`if`(!is.null(input$height), input$height, height[1]))
-    p_width <- reactive(`if`(!is.null(input$width), input$width, default_slider_width()[1]))
+    p_height <- reactive(if (!is.null(input$height)) input$height else height[1])
+    p_width <- reactive(
+      if (!is.null(input$width)) {
+        input$width
+      } else {
+        if (!is.null(default_slider_width()[1])) {
+          default_slider_width()[1]
+        } else {
+          # Fallback to "auto"
+          "auto"
+        }
+      }
+    )
     output$plot_main <- renderPlot(
       apply_plot_modifications(
         plot_obj = plot_suppress(plot_r()),
@@ -411,7 +421,7 @@ plot_with_settings_srv <- function(id,
 
     output$plot_out_main <- renderUI({
       req(plot_suppress(plot_r()))
-      div(
+      tags$div(
         align = graph_align,
         plotOutput(
           ns("plot_main"),
@@ -425,7 +435,7 @@ plot_with_settings_srv <- function(id,
     })
 
     output$width_warning <- renderUI({
-      grDevices::pdf(NULL) # reset Rplots.pdf for shiny server
+      grDevices::pdf(nullfile()) # reset Rplots.pdf for shiny server
       w <- grDevices::dev.size("px")[1]
       grDevices::dev.off()
       if (p_width() < w) {
@@ -452,11 +462,11 @@ plot_with_settings_srv <- function(id,
 
     observeEvent(input$expand, {
       showModal(
-        div(
+        tags$div(
           class = "plot-modal",
           modalDialog(
             easyClose = TRUE,
-            div(
+            tags$div(
               class = "plot-modal-sliders",
               optionalSliderInputValMinMax(
                 inputId = ns("height_in_modal"),
@@ -486,11 +496,11 @@ plot_with_settings_srv <- function(id,
                 round = TRUE
               )
             ),
-            div(
+            tags$div(
               class = "float-right",
               type_download_ui(ns("modal_downbutton"))
             ),
-            div(
+            tags$div(
               align = "center",
               uiOutput(ns("plot_out_modal"), class = "plot_out_container")
             )
@@ -546,12 +556,13 @@ type_download_ui <- function(id) {
   ns <- NS(id)
   shinyWidgets::dropdownButton(
     circle = FALSE,
+    size = "sm",
     icon = icon("download"),
     inline = TRUE,
     right = TRUE,
     label = "",
     inputId = ns("downl"),
-    div(
+    tags$div(
       radioButtons(ns("file_format"),
         label = "File type",
         choices = c("png" = "png", "pdf" = "pdf", "svg" = "svg"),
@@ -597,18 +608,42 @@ type_download_srv <- function(id, plot_reactive, plot_type, plot_w, default_w, p
   )
 }
 
-#' Cleans and organizes output to account for NAs and remove empty rows.
+#' Clean brushed points
 #'
-#' @description `r lifecycle::badge("stable")`
+#' @description `r lifecycle::badge("stable")`\cr
+#' Cleans and organizes output to account for NAs and remove empty rows. Wrapper around `shiny::brushedPoints`.
 #' @param data (`data.frame`)\cr
-#'  A dataframe from which to select rows.
+#'  A data.frame from which to select rows.
 #' @param brush (`list`)\cr
-#'  The data from a brush e.g. input$plot_brush.
+#'  The data from a brush e.g. `input$plot_brush`.
+#'
+#' @return A `data.frame` of selected rows.
+#'
+#' @examples
+#'
+#' brush <- list(
+#'   mapping = list(
+#'     x = "AGE",
+#'     y = "BMRKR1"
+#'   ),
+#'   xmin = 30, xmax = 40,
+#'   ymin = 0.7, ymax = 10,
+#'   direction = "xy"
+#' )
+#'
+#' data <- data.frame(
+#'   STUDYID = letters[1:20],
+#'   USUBJID = LETTERS[1:20],
+#'   AGE = sample(25:40, size = 20, replace = TRUE),
+#'   BMRKR1 = runif(20, min = 0, max = 12)
+#' )
+#' nrow(clean_brushedPoints(data, brush))
+#' data$AGE[1:10] <- NA
+#' nrow(clean_brushedPoints(data, brush))
 #'
-#' @return A dataframe of selected rows.
 #' @export
 #'
-clean_brushedPoints <- function(data, brush) { # nolintr
+clean_brushedPoints <- function(data, brush) { # nolint object_name_linter.
   checkmate::assert_data_frame(data)
   checkmate::assert_list(brush, null.ok = TRUE)
 
