@@ -1,8 +1,21 @@
+#' @keywords internal
+#' @noRd
+table_with_settings_deps <- function() {
+  htmltools::htmlDependency(
+    name = "teal-widgets-table-with-settings",
+    version = utils::packageVersion("teal.widgets"),
+    package = "teal.widgets",
+    src = "table-with-settings",
+    stylesheet = "table-with-settings.css"
+  )
+}
+
 #' @name table_with_settings
 #'
-#' @title table_with_settings module
+#' @title `table_with_settings` module
 #'
-#' @description `r lifecycle::badge("stable")`
+#' @description `r lifecycle::badge("stable")`\cr
+#' Module designed to create a `shiny` table output based on `rtable` object (`ElementaryTable` or `TableTree`) input.
 #' @inheritParams shiny::moduleServer
 #' @param ... (`character`)\cr
 #'  Useful for providing additional HTML classes for the output tag.
@@ -16,7 +29,7 @@ table_with_settings_ui <- function(id, ...) {
   ns <- NS(id)
 
   tagList(
-    include_css_files("table_with_settings"),
+    table_with_settings_deps(),
     tags$div(
       id = ns("table-with-settings"),
       tags$div(
@@ -38,8 +51,8 @@ table_with_settings_ui <- function(id, ...) {
 #' @inheritParams shiny::moduleServer
 #' @param table_r (`reactive`)\cr
 #'  reactive expression that yields an `rtable` object (`ElementaryTable` or `TableTree`)
-#' @param show_hide_signal (`reactive logical`, optional)\cr
-#'  a mechanism to allow modules which call this module to show/hide the table_with_settings UI.
+#' @param show_hide_signal (`reactive logical`) optional\cr
+#'  mechanism to allow modules which call this module to show/hide the table_with_settings UI.
 #'
 #' @rdname table_with_settings
 #'
@@ -51,28 +64,29 @@ table_with_settings_ui <- function(id, ...) {
 #' library(shiny)
 #' library(rtables)
 #' library(magrittr)
-#' app <- shinyApp(
-#'   ui = fluidPage(
-#'     table_with_settings_ui(
-#'       id = "table_with_settings"
-#'     )
-#'   ),
-#'   server = function(input, output, session) {
-#'     table_r <- reactive({
-#'       l <- basic_table() %>%
-#'         split_cols_by("ARM") %>%
-#'         analyze(c("SEX", "AGE"))
 #'
-#'       tbl <- build_table(l, DM)
-#'
-#'       tbl
-#'     })
-#'
-#'     table_with_settings_srv(id = "table_with_settings", table_r = table_r)
-#'   }
+#' ui <- fluidPage(
+#'   table_with_settings_ui(
+#'     id = "table_with_settings"
+#'   )
 #' )
+#'
+#' server <- function(input, output, session) {
+#'   table_r <- reactive({
+#'     l <- basic_table() %>%
+#'       split_cols_by("ARM") %>%
+#'       analyze(c("SEX", "AGE"))
+#'
+#'     tbl <- build_table(l, DM)
+#'
+#'     tbl
+#'   })
+#'
+#'   table_with_settings_srv(id = "table_with_settings", table_r = table_r)
+#' }
+#'
 #' if (interactive()) {
-#'   app
+#'   shinyApp(ui, server)
 #' }
 #'
 table_with_settings_srv <- function(id, table_r, show_hide_signal = reactive(TRUE)) {
@@ -105,11 +119,11 @@ table_with_settings_srv <- function(id, table_r, show_hide_signal = reactive(TRU
 
     observeEvent(input$expand, {
       showModal(
-        div(
+        tags$div(
           class = "table-modal",
           modalDialog(
             easyClose = TRUE,
-            div(
+            tags$div(
               class = "float-right",
               type_download_ui_table(ns("modal_downbutton"))
             ),
@@ -135,7 +149,7 @@ type_download_ui_table <- function(id) {
     right = TRUE,
     label = "",
     inputId = ns("dwnl"),
-    div(
+    tags$div(
       class = "modal-download-ui-table-container",
       radioButtons(ns("file_format"),
         label = "File type",
@@ -147,7 +161,7 @@ type_download_ui_table <- function(id) {
       ),
       conditionalPanel(
         condition = paste0("input['", ns("file_format"), "'] != '.csv'"),
-        div(
+        tags$div(
           class = "lock-btn",
           title = "on / off",
           shinyWidgets::prettyToggle(
@@ -164,7 +178,7 @@ type_download_ui_table <- function(id) {
             animation = "pulse"
           )
         ),
-        div(
+        tags$div(
           class = "paginate-ui",
           shinyWidgets::numericInputIcon(
             inputId = ns("lpp"),
@@ -200,7 +214,7 @@ type_download_srv_table <- function(id, table_reactive) {
           try(rtables::paginate_table(
             tt = table_reactive(),
             lpp = as.numeric(input$lpp)
-          ))
+          ), silent = TRUE)
         }
 
         if (inherits(catch_warning, "try-error")) {
